library(glmnet)
library(mboost)
library(stringi)


data("riboflavin", package = "hdi")


#glmnet
x = riboflavin[,-1]
colnames(x) = stri_replace_all(colnames(x), replacement = "", fixed = "_")
y = riboflavin[,1]
data = data.frame(cbind(y, x, matrix(sample(x), nrow = 71)))

fit = glmnet(x = x, y = y)
set.seed(42)
fit.cv = cv.glmnet(x = x, y = y)
b = as.matrix(coef(fit.cv))
b = rownames(b)[b != 0]

b = b[b != "(Intercept)"]

#probing
set.seed(42)
mod = glmboost(y ~ ., data = data.frame(data), probe = TRUE, control = boost_control(mstop = 1000))
b2 = names(coef(mod))
b2 = b2[b2 != "(Intercept)"]

#CV
set.seed(123)
mod = glmboost(y ~ ., data = data.frame(data), control = boost_control(mstop = 500))
opt = cvrisk(mod, papply = lapply)
mstop(mod) = mstop(opt)
b3 = names(coef(mod))
b3 = substring(b3[-1], 2)

#stabsel
set.seed(13)
stabs = stabsel(mod, PFER = 1, q = 20, papply = lapply)
b4 = names(selected(stabs))
b4 = substring(b4, 2)

selections = list(
  glmnet = b,
  probing = b2,
  cv = b3,
  stabsel = b4
)


selectionSimilarities = function(l) {
  m = length(l)
  res = matrix(NA, ncol = m, nrow = m)
  colnames(res) = rownames(res) = names(l)
  
  for(i in names(l)) {
    for(j in names(l)) {
      res[i,j] = sum(l[[i]] %in% l[[j]]) 
    }
  }
  res
}


selectionSimilarities(selections)



