library(batchtools)
source("defs.R")

reg = loadRegistry("registry/", work.dir = ".")


full_res = list()

for(e in getProblemIds()) {
  
  p = as.numeric(strsplit(e, split = "P|N")[[1]][2])
  n = as.numeric(strsplit(e, split = "N|I")[[1]][2])
  inf = as.numeric(strsplit(e, split = "Inf")[[1]][2])
  
  #probing
  res = reduceResultsList(findExperiments(prob.name = e, algo.name = "probing"))
  probing = data.frame(do.call(rbind, res), p = p, n = n, inf = inf, method = "probing") 
  
  #cv
  res = reduceResultsList(findExperiments(prob.name = e, algo.name = "crossval"))
  cv = data.frame(do.call(rbind, res), p = p, n = n, inf = inf, method = "crossval")
  
  #stabsel
  pars = expand.grid(PI, PFER)
  res = do.call(rbind, mapply(function(p, pf) {
    res = reduceResultsList(findExperiments(prob.name = e, algo.name = "stabsel", algo.pars = pi == p && pfer == pf))
    data.frame(do.call(rbind, res), method = paste0("stabsel_pi", p, "_pfer", pf))}, 
    p = pars[,1], pf = pars[,2], SIMPLIFY = FALSE))
  stabs = data.frame(res, p = p, n = n, inf = inf)
  
  full_res[[e]] = rbind(probing, cv, stabs)
}

data = do.call(rbind, full_res)
# something strange is happening here
data$tpr = unlist(data$tpr)
data$fpr = unlist(data$fpr)
data$runtime = unlist(data$runtime)
data$mmce = unlist(data$mmce)
data$mmce_mle = unlist(data$mmce_mle)
data$mstop = unlist(data$mstop)


library(ggplot2)
pdf("results.pdf")
ggplot(data = data) + geom_boxplot(aes(y = tpr, x = method, fill = method), position = "dodge") + 
  facet_grid(p + inf ~ n) + ggtitle("tpr")
ggplot(data = data) + geom_boxplot(aes(y = fpr, x = method, fill = method), position = "dodge") + 
  facet_grid(p + inf ~ n) + ggtitle("fpr")
ggplot(data = data) + geom_boxplot(aes(y = runtime, x = method, fill = method), position = "dodge") + 
  facet_grid(p + inf ~ n) + ggtitle("runtime")
ggplot(data = data) + geom_boxplot(aes(y = mmce, x = method, fill = method), position = "dodge") + 
  facet_grid(p + inf ~ n) + ggtitle("mmce")
ggplot(data = data) + geom_boxplot(aes(y = mmce_mle, x = method, fill = method), position = "dodge") + 
  facet_grid(p + inf ~ n) + ggtitle("mmce_mle")
ggplot(data = data) + geom_boxplot(aes(y = mstop, x = method, fill = method), position = "dodge") + 
  facet_grid(p + inf ~ n) + ggtitle("mstop")
dev.off()



library(dplyr)
library(tidyr)
library(aplpack)

data %>%
  filter(method %in% c("probing", "crossval", "stabsel_pi0.75_pfer2.5")) %>% 
  group_by(p, n, inf, method) %>% 
  select(tpr, fpr) %>% 
  summarise(firstfpr = quantile(fpr, probs = 0.25), thirdfpr = quantile(fpr, probs = 0.75),
    firsttpr = quantile(tpr, probs = 0.25), thirdtpr = quantile(tpr, probs = 0.75),
    medtpr = quantile(tpr, probs = 0.5), medfpr = quantile(fpr, probs = 0.55)) %>% 
  ggplot() + geom_segment(aes(y = firsttpr, x = medfpr, yend = thirdtpr, xend = medfpr, color = method), size = 1) +
  geom_segment(aes(y = medtpr, x = firstfpr, yend = medtpr, xend = thirdfpr, color = method), size = 1) +
  facet_grid(p + inf ~ n, scales = "free") + xlab("fpr") + ylab("tpr")
  
data %>%
  filter(method %in% c("probing", "crossval", "stabsel_pi0.75_pfer2.5")) %>% 
  filter(p == 100, n == 100, inf == 5) %>% 
  ggplot(aes(tpr, fpr, colour = method, fill = method)) +
  geom_bag() +
  geom_point() +
 # facet_grid(p + inf ~ n, scales = "free") + xlab("fpr") + ylab("tpr") +
  theme_minimal()

